// Compiled by ClojureScript 1.10.238 {:target :nodejs}
goog.provide('cljs.source_map');
goog.require('cljs.core');
goog.require('goog.object');
goog.require('clojure.string');
goog.require('clojure.set');
goog.require('cljs.source_map.base64_vlq');
/**
 * Take a seq of source file names and return a map from
 * file number to integer index. For reverse source maps.
 */
cljs.source_map.indexed_sources = (function cljs$source_map$indexed_sources(sources){
return cljs.core.reduce.call(null,(function (m,p__6215){
var vec__6216 = p__6215;
var i = cljs.core.nth.call(null,vec__6216,(0),null);
var v = cljs.core.nth.call(null,vec__6216,(1),null);
return cljs.core.assoc.call(null,m,v,i);
}),cljs.core.PersistentArrayMap.EMPTY,cljs.core.map_indexed.call(null,(function (a,b){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [a,b], null);
}),sources));
});
/**
 * Take a seq of source file names and return a comparator
 * that can be used to construct a sorted map. For reverse
 * source maps.
 */
cljs.source_map.source_compare = (function cljs$source_map$source_compare(sources){
var sources__$1 = cljs.source_map.indexed_sources.call(null,sources);
return ((function (sources__$1){
return (function (a,b){
return cljs.core.compare.call(null,sources__$1.call(null,a),sources__$1.call(null,b));
});
;})(sources__$1))
});
/**
 * Take a source map segment represented as a vector
 * and return a map.
 */
cljs.source_map.seg__GT_map = (function cljs$source_map$seg__GT_map(seg,source_map){
var vec__6219 = seg;
var gcol = cljs.core.nth.call(null,vec__6219,(0),null);
var source = cljs.core.nth.call(null,vec__6219,(1),null);
var line = cljs.core.nth.call(null,vec__6219,(2),null);
var col = cljs.core.nth.call(null,vec__6219,(3),null);
var name = cljs.core.nth.call(null,vec__6219,(4),null);
return new cljs.core.PersistentArrayMap(null, 5, [new cljs.core.Keyword(null,"gcol","gcol",309250807),gcol,new cljs.core.Keyword(null,"source","source",-433931539),(goog.object.get(source_map,"sources")[source]),new cljs.core.Keyword(null,"line","line",212345235),line,new cljs.core.Keyword(null,"col","col",-1959363084),col,new cljs.core.Keyword(null,"name","name",1843675177),(function (){var temp__6753__auto__ = new cljs.core.Keyword(null,"name","name",1843675177).cljs$core$IFn$_invoke$arity$1(cljs.core.meta.call(null,seg));
if(cljs.core.truth_(temp__6753__auto__)){
var name__$1 = temp__6753__auto__;
return (goog.object.get(source_map,"names")[name__$1]);
} else {
return null;
}
})()], null);
});
/**
 * Combine a source map segment vector and a relative
 * source map segment vector and combine them to get
 * an absolute segment posititon information as a vector.
 */
cljs.source_map.seg_combine = (function cljs$source_map$seg_combine(seg,relseg){
var vec__6222 = seg;
var gcol = cljs.core.nth.call(null,vec__6222,(0),null);
var source = cljs.core.nth.call(null,vec__6222,(1),null);
var line = cljs.core.nth.call(null,vec__6222,(2),null);
var col = cljs.core.nth.call(null,vec__6222,(3),null);
var name = cljs.core.nth.call(null,vec__6222,(4),null);
var vec__6225 = relseg;
var rgcol = cljs.core.nth.call(null,vec__6225,(0),null);
var rsource = cljs.core.nth.call(null,vec__6225,(1),null);
var rline = cljs.core.nth.call(null,vec__6225,(2),null);
var rcol = cljs.core.nth.call(null,vec__6225,(3),null);
var rname = cljs.core.nth.call(null,vec__6225,(4),null);
var nseg = new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [(gcol + rgcol),((function (){var or__3922__auto__ = source;
if(cljs.core.truth_(or__3922__auto__)){
return or__3922__auto__;
} else {
return (0);
}
})() + rsource),((function (){var or__3922__auto__ = line;
if(cljs.core.truth_(or__3922__auto__)){
return or__3922__auto__;
} else {
return (0);
}
})() + rline),((function (){var or__3922__auto__ = col;
if(cljs.core.truth_(or__3922__auto__)){
return or__3922__auto__;
} else {
return (0);
}
})() + rcol),((function (){var or__3922__auto__ = name;
if(cljs.core.truth_(or__3922__auto__)){
return or__3922__auto__;
} else {
return (0);
}
})() + rname)], null);
if(cljs.core.truth_(name)){
return cljs.core.with_meta.call(null,nseg,new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"name","name",1843675177),(name + rname)], null));
} else {
return nseg;
}
});
/**
 * Helper for decode-reverse. Take a reverse source map and
 *   update it with a segment map.
 */
cljs.source_map.update_reverse_result = (function cljs$source_map$update_reverse_result(result,segmap,gline){
var map__6228 = segmap;
var map__6228__$1 = ((((!((map__6228 == null)))?(((((map__6228.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__6228.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__6228):map__6228);
var gcol = cljs.core.get.call(null,map__6228__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var source = cljs.core.get.call(null,map__6228__$1,new cljs.core.Keyword(null,"source","source",-433931539));
var line = cljs.core.get.call(null,map__6228__$1,new cljs.core.Keyword(null,"line","line",212345235));
var col = cljs.core.get.call(null,map__6228__$1,new cljs.core.Keyword(null,"col","col",-1959363084));
var name = cljs.core.get.call(null,map__6228__$1,new cljs.core.Keyword(null,"name","name",1843675177));
var d = new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"gline","gline",-1086242431),gline,new cljs.core.Keyword(null,"gcol","gcol",309250807),gcol], null);
var d__$1 = (cljs.core.truth_(name)?cljs.core.assoc.call(null,d,new cljs.core.Keyword(null,"name","name",1843675177),name):d);
return cljs.core.update_in.call(null,result,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [source], null),cljs.core.fnil.call(null,((function (map__6228,map__6228__$1,gcol,source,line,col,name,d,d__$1){
return (function (m){
return cljs.core.update_in.call(null,m,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [line], null),cljs.core.fnil.call(null,((function (map__6228,map__6228__$1,gcol,source,line,col,name,d,d__$1){
return (function (m__$1){
return cljs.core.update_in.call(null,m__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [col], null),cljs.core.fnil.call(null,((function (map__6228,map__6228__$1,gcol,source,line,col,name,d,d__$1){
return (function (v){
return cljs.core.conj.call(null,v,d__$1);
});})(map__6228,map__6228__$1,gcol,source,line,col,name,d,d__$1))
,cljs.core.PersistentVector.EMPTY));
});})(map__6228,map__6228__$1,gcol,source,line,col,name,d,d__$1))
,cljs.core.sorted_map.call(null)));
});})(map__6228,map__6228__$1,gcol,source,line,col,name,d,d__$1))
,cljs.core.sorted_map.call(null)));
});
/**
 * Convert a v3 source map JSON object into a reverse source map
 *   mapping original ClojureScript source locations to the generated
 *   JavaScript.
 */
cljs.source_map.decode_reverse = (function cljs$source_map$decode_reverse(var_args){
var G__6231 = arguments.length;
switch (G__6231) {
case 1:
return cljs.source_map.decode_reverse.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 2:
return cljs.source_map.decode_reverse.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

cljs.source_map.decode_reverse.cljs$core$IFn$_invoke$arity$1 = (function (source_map){
return cljs.source_map.decode_reverse.call(null,goog.object.get(source_map,"mappings"),source_map);
});

cljs.source_map.decode_reverse.cljs$core$IFn$_invoke$arity$2 = (function (mappings,source_map){
var sources = goog.object.get(source_map,"sources");
var relseg_init = new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [(0),(0),(0),(0),(0)], null);
var lines = cljs.core.seq.call(null,clojure.string.split.call(null,mappings,/;/));
var gline = (0);
var lines__$1 = lines;
var relseg = relseg_init;
var result = cljs.core.sorted_map_by.call(null,cljs.source_map.source_compare.call(null,sources));
while(true){
if(lines__$1){
var line = cljs.core.first.call(null,lines__$1);
var vec__6232 = ((clojure.string.blank_QMARK_.call(null,line))?new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [result,relseg], null):(function (){var segs = cljs.core.seq.call(null,clojure.string.split.call(null,line,/,/));
var segs__$1 = segs;
var relseg__$1 = relseg;
var result__$1 = result;
while(true){
if(segs__$1){
var seg = cljs.core.first.call(null,segs__$1);
var nrelseg = cljs.source_map.seg_combine.call(null,cljs.source_map.base64_vlq.decode.call(null,seg),relseg__$1);
var G__6236 = cljs.core.next.call(null,segs__$1);
var G__6237 = nrelseg;
var G__6238 = cljs.source_map.update_reverse_result.call(null,result__$1,cljs.source_map.seg__GT_map.call(null,nrelseg,source_map),gline);
segs__$1 = G__6236;
relseg__$1 = G__6237;
result__$1 = G__6238;
continue;
} else {
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [result__$1,relseg__$1], null);
}
break;
}
})());
var result__$1 = cljs.core.nth.call(null,vec__6232,(0),null);
var relseg__$1 = cljs.core.nth.call(null,vec__6232,(1),null);
var G__6239 = (gline + (1));
var G__6240 = cljs.core.next.call(null,lines__$1);
var G__6241 = cljs.core.assoc.call(null,relseg__$1,(0),(0));
var G__6242 = result__$1;
gline = G__6239;
lines__$1 = G__6240;
relseg = G__6241;
result = G__6242;
continue;
} else {
return result;
}
break;
}
});

cljs.source_map.decode_reverse.cljs$lang$maxFixedArity = 2;

/**
 * Helper for decode. Take a source map and update it based on a
 *   segment map.
 */
cljs.source_map.update_result = (function cljs$source_map$update_result(result,segmap,gline){
var map__6244 = segmap;
var map__6244__$1 = ((((!((map__6244 == null)))?(((((map__6244.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__6244.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__6244):map__6244);
var gcol = cljs.core.get.call(null,map__6244__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var source = cljs.core.get.call(null,map__6244__$1,new cljs.core.Keyword(null,"source","source",-433931539));
var line = cljs.core.get.call(null,map__6244__$1,new cljs.core.Keyword(null,"line","line",212345235));
var col = cljs.core.get.call(null,map__6244__$1,new cljs.core.Keyword(null,"col","col",-1959363084));
var name = cljs.core.get.call(null,map__6244__$1,new cljs.core.Keyword(null,"name","name",1843675177));
var d = new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line,new cljs.core.Keyword(null,"col","col",-1959363084),col,new cljs.core.Keyword(null,"source","source",-433931539),source], null);
var d__$1 = (cljs.core.truth_(name)?cljs.core.assoc.call(null,d,new cljs.core.Keyword(null,"name","name",1843675177),name):d);
return cljs.core.update_in.call(null,result,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline], null),cljs.core.fnil.call(null,((function (map__6244,map__6244__$1,gcol,source,line,col,name,d,d__$1){
return (function (m){
return cljs.core.update_in.call(null,m,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol], null),cljs.core.fnil.call(null,((function (map__6244,map__6244__$1,gcol,source,line,col,name,d,d__$1){
return (function (p1__6243_SHARP_){
return cljs.core.conj.call(null,p1__6243_SHARP_,d__$1);
});})(map__6244,map__6244__$1,gcol,source,line,col,name,d,d__$1))
,cljs.core.PersistentVector.EMPTY));
});})(map__6244,map__6244__$1,gcol,source,line,col,name,d,d__$1))
,cljs.core.sorted_map.call(null)));
});
/**
 * Convert a v3 source map JSON object into a source map mapping
 *   generated JavaScript source locations to the original
 *   ClojureScript.
 */
cljs.source_map.decode = (function cljs$source_map$decode(var_args){
var G__6247 = arguments.length;
switch (G__6247) {
case 1:
return cljs.source_map.decode.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 2:
return cljs.source_map.decode.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

cljs.source_map.decode.cljs$core$IFn$_invoke$arity$1 = (function (source_map){
return cljs.source_map.decode.call(null,goog.object.get(source_map,"mappings"),source_map);
});

cljs.source_map.decode.cljs$core$IFn$_invoke$arity$2 = (function (mappings,source_map){
var sources = goog.object.get(source_map,"sources");
var relseg_init = new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [(0),(0),(0),(0),(0)], null);
var lines = cljs.core.seq.call(null,clojure.string.split.call(null,mappings,/;/));
var gline = (0);
var lines__$1 = lines;
var relseg = relseg_init;
var result = cljs.core.PersistentArrayMap.EMPTY;
while(true){
if(lines__$1){
var line = cljs.core.first.call(null,lines__$1);
var vec__6248 = ((clojure.string.blank_QMARK_.call(null,line))?new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [result,relseg], null):(function (){var segs = cljs.core.seq.call(null,clojure.string.split.call(null,line,/,/));
var segs__$1 = segs;
var relseg__$1 = relseg;
var result__$1 = result;
while(true){
if(segs__$1){
var seg = cljs.core.first.call(null,segs__$1);
var nrelseg = cljs.source_map.seg_combine.call(null,cljs.source_map.base64_vlq.decode.call(null,seg),relseg__$1);
var G__6252 = cljs.core.next.call(null,segs__$1);
var G__6253 = nrelseg;
var G__6254 = cljs.source_map.update_result.call(null,result__$1,cljs.source_map.seg__GT_map.call(null,nrelseg,source_map),gline);
segs__$1 = G__6252;
relseg__$1 = G__6253;
result__$1 = G__6254;
continue;
} else {
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [result__$1,relseg__$1], null);
}
break;
}
})());
var result__$1 = cljs.core.nth.call(null,vec__6248,(0),null);
var relseg__$1 = cljs.core.nth.call(null,vec__6248,(1),null);
var G__6255 = (gline + (1));
var G__6256 = cljs.core.next.call(null,lines__$1);
var G__6257 = cljs.core.assoc.call(null,relseg__$1,(0),(0));
var G__6258 = result__$1;
gline = G__6255;
lines__$1 = G__6256;
relseg = G__6257;
result = G__6258;
continue;
} else {
return result;
}
break;
}
});

cljs.source_map.decode.cljs$lang$maxFixedArity = 2;

/**
 * Take a nested sorted map encoding line and column information
 * for a file and return a vector of vectors of encoded segments.
 * Each vector represents a line, and the internal vectors are segments
 * representing the contents of the line.
 */
cljs.source_map.lines__GT_segs = (function cljs$source_map$lines__GT_segs(lines){
var relseg = cljs.core.atom.call(null,new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [(0),(0),(0),(0),(0)], null));
return cljs.core.reduce.call(null,((function (relseg){
return (function (segs,cols){
cljs.core.swap_BANG_.call(null,relseg,((function (relseg){
return (function (p__6259){
var vec__6260 = p__6259;
var _ = cljs.core.nth.call(null,vec__6260,(0),null);
var source = cljs.core.nth.call(null,vec__6260,(1),null);
var line = cljs.core.nth.call(null,vec__6260,(2),null);
var col = cljs.core.nth.call(null,vec__6260,(3),null);
var name = cljs.core.nth.call(null,vec__6260,(4),null);
return new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [(0),source,line,col,name], null);
});})(relseg))
);

return cljs.core.conj.call(null,segs,cljs.core.reduce.call(null,((function (relseg){
return (function (cols__$1,p__6263){
var vec__6264 = p__6263;
var gcol = cljs.core.nth.call(null,vec__6264,(0),null);
var sidx = cljs.core.nth.call(null,vec__6264,(1),null);
var line = cljs.core.nth.call(null,vec__6264,(2),null);
var col = cljs.core.nth.call(null,vec__6264,(3),null);
var name = cljs.core.nth.call(null,vec__6264,(4),null);
var seg = vec__6264;
var offset = cljs.core.map.call(null,cljs.core._,seg,cljs.core.deref.call(null,relseg));
cljs.core.swap_BANG_.call(null,relseg,((function (offset,vec__6264,gcol,sidx,line,col,name,seg,relseg){
return (function (p__6267){
var vec__6268 = p__6267;
var _ = cljs.core.nth.call(null,vec__6268,(0),null);
var ___$1 = cljs.core.nth.call(null,vec__6268,(1),null);
var ___$2 = cljs.core.nth.call(null,vec__6268,(2),null);
var ___$3 = cljs.core.nth.call(null,vec__6268,(3),null);
var lname = cljs.core.nth.call(null,vec__6268,(4),null);
return new cljs.core.PersistentVector(null, 5, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol,sidx,line,col,(function (){var or__3922__auto__ = name;
if(cljs.core.truth_(or__3922__auto__)){
return or__3922__auto__;
} else {
return lname;
}
})()], null);
});})(offset,vec__6264,gcol,sidx,line,col,name,seg,relseg))
);

return cljs.core.conj.call(null,cols__$1,cljs.source_map.base64_vlq.encode.call(null,offset));
});})(relseg))
,cljs.core.PersistentVector.EMPTY,cols));
});})(relseg))
,cljs.core.PersistentVector.EMPTY,lines);
});
/**
 * Take an internal source map representation represented as nested
 * sorted maps of file, line, column and return a source map v3 JSON
 * string.
 */
cljs.source_map.encode = (function cljs$source_map$encode(m,opts){
var lines = cljs.core.atom.call(null,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [cljs.core.PersistentVector.EMPTY], null));
var names__GT_idx = cljs.core.atom.call(null,cljs.core.PersistentArrayMap.EMPTY);
var name_idx = cljs.core.atom.call(null,(0));
var preamble_lines = cljs.core.take.call(null,(function (){var or__3922__auto__ = new cljs.core.Keyword(null,"preamble-line-count","preamble-line-count",-659949744).cljs$core$IFn$_invoke$arity$1(opts);
if(cljs.core.truth_(or__3922__auto__)){
return or__3922__auto__;
} else {
return (0);
}
})(),cljs.core.repeat.call(null,cljs.core.PersistentVector.EMPTY));
var info__GT_segv = ((function (lines,names__GT_idx,name_idx,preamble_lines){
return (function (info,source_idx,line,col){
var segv = new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"gcol","gcol",309250807).cljs$core$IFn$_invoke$arity$1(info),source_idx,line,col], null);
var temp__6751__auto__ = new cljs.core.Keyword(null,"name","name",1843675177).cljs$core$IFn$_invoke$arity$1(info);
if(cljs.core.truth_(temp__6751__auto__)){
var name = temp__6751__auto__;
var idx = (function (){var temp__6751__auto____$1 = cljs.core.get.call(null,cljs.core.deref.call(null,names__GT_idx),name);
if(cljs.core.truth_(temp__6751__auto____$1)){
var idx = temp__6751__auto____$1;
return idx;
} else {
var cidx = cljs.core.deref.call(null,name_idx);
cljs.core.swap_BANG_.call(null,names__GT_idx,cljs.core.assoc,name,cidx);

cljs.core.swap_BANG_.call(null,name_idx,cljs.core.inc);

return cidx;
}
})();
return cljs.core.conj.call(null,segv,idx);
} else {
return segv;
}
});})(lines,names__GT_idx,name_idx,preamble_lines))
;
var encode_cols = ((function (lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv){
return (function (infos,source_idx,line,col){
var seq__6274 = cljs.core.seq.call(null,infos);
var chunk__6275 = null;
var count__6276 = (0);
var i__6277 = (0);
while(true){
if((i__6277 < count__6276)){
var info = cljs.core._nth.call(null,chunk__6275,i__6277);
var segv_6356 = info__GT_segv.call(null,info,source_idx,line,col);
var gline_6357 = new cljs.core.Keyword(null,"gline","gline",-1086242431).cljs$core$IFn$_invoke$arity$1(info);
var lc_6358 = cljs.core.count.call(null,cljs.core.deref.call(null,lines));
if((gline_6357 > (lc_6358 - (1)))){
cljs.core.swap_BANG_.call(null,lines,((function (seq__6274,chunk__6275,count__6276,i__6277,segv_6356,gline_6357,lc_6358,info,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv){
return (function (lines__$1){
return cljs.core.conj.call(null,cljs.core.into.call(null,lines__$1,cljs.core.repeat.call(null,((gline_6357 - (lc_6358 - (1))) - (1)),cljs.core.PersistentVector.EMPTY)),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [segv_6356], null));
});})(seq__6274,chunk__6275,count__6276,i__6277,segv_6356,gline_6357,lc_6358,info,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv))
);
} else {
cljs.core.swap_BANG_.call(null,lines,((function (seq__6274,chunk__6275,count__6276,i__6277,segv_6356,gline_6357,lc_6358,info,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv){
return (function (lines__$1){
return cljs.core.update_in.call(null,lines__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_6357], null),cljs.core.conj,segv_6356);
});})(seq__6274,chunk__6275,count__6276,i__6277,segv_6356,gline_6357,lc_6358,info,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv))
);
}


var G__6359 = seq__6274;
var G__6360 = chunk__6275;
var G__6361 = count__6276;
var G__6362 = (i__6277 + (1));
seq__6274 = G__6359;
chunk__6275 = G__6360;
count__6276 = G__6361;
i__6277 = G__6362;
continue;
} else {
var temp__6753__auto__ = cljs.core.seq.call(null,seq__6274);
if(temp__6753__auto__){
var seq__6274__$1 = temp__6753__auto__;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6274__$1)){
var c__4319__auto__ = cljs.core.chunk_first.call(null,seq__6274__$1);
var G__6363 = cljs.core.chunk_rest.call(null,seq__6274__$1);
var G__6364 = c__4319__auto__;
var G__6365 = cljs.core.count.call(null,c__4319__auto__);
var G__6366 = (0);
seq__6274 = G__6363;
chunk__6275 = G__6364;
count__6276 = G__6365;
i__6277 = G__6366;
continue;
} else {
var info = cljs.core.first.call(null,seq__6274__$1);
var segv_6367 = info__GT_segv.call(null,info,source_idx,line,col);
var gline_6368 = new cljs.core.Keyword(null,"gline","gline",-1086242431).cljs$core$IFn$_invoke$arity$1(info);
var lc_6369 = cljs.core.count.call(null,cljs.core.deref.call(null,lines));
if((gline_6368 > (lc_6369 - (1)))){
cljs.core.swap_BANG_.call(null,lines,((function (seq__6274,chunk__6275,count__6276,i__6277,segv_6367,gline_6368,lc_6369,info,seq__6274__$1,temp__6753__auto__,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv){
return (function (lines__$1){
return cljs.core.conj.call(null,cljs.core.into.call(null,lines__$1,cljs.core.repeat.call(null,((gline_6368 - (lc_6369 - (1))) - (1)),cljs.core.PersistentVector.EMPTY)),new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [segv_6367], null));
});})(seq__6274,chunk__6275,count__6276,i__6277,segv_6367,gline_6368,lc_6369,info,seq__6274__$1,temp__6753__auto__,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv))
);
} else {
cljs.core.swap_BANG_.call(null,lines,((function (seq__6274,chunk__6275,count__6276,i__6277,segv_6367,gline_6368,lc_6369,info,seq__6274__$1,temp__6753__auto__,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv){
return (function (lines__$1){
return cljs.core.update_in.call(null,lines__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_6368], null),cljs.core.conj,segv_6367);
});})(seq__6274,chunk__6275,count__6276,i__6277,segv_6367,gline_6368,lc_6369,info,seq__6274__$1,temp__6753__auto__,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv))
);
}


var G__6370 = cljs.core.next.call(null,seq__6274__$1);
var G__6371 = null;
var G__6372 = (0);
var G__6373 = (0);
seq__6274 = G__6370;
chunk__6275 = G__6371;
count__6276 = G__6372;
i__6277 = G__6373;
continue;
}
} else {
return null;
}
}
break;
}
});})(lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv))
;
var seq__6278_6374 = cljs.core.seq.call(null,cljs.core.map_indexed.call(null,((function (lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols){
return (function (i,v){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [i,v], null);
});})(lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols))
,m));
var chunk__6279_6375 = null;
var count__6280_6376 = (0);
var i__6281_6377 = (0);
while(true){
if((i__6281_6377 < count__6280_6376)){
var vec__6282_6378 = cljs.core._nth.call(null,chunk__6279_6375,i__6281_6377);
var source_idx_6379 = cljs.core.nth.call(null,vec__6282_6378,(0),null);
var vec__6285_6380 = cljs.core.nth.call(null,vec__6282_6378,(1),null);
var __6381 = cljs.core.nth.call(null,vec__6285_6380,(0),null);
var lines_6382__$1 = cljs.core.nth.call(null,vec__6285_6380,(1),null);
var seq__6288_6383 = cljs.core.seq.call(null,lines_6382__$1);
var chunk__6289_6384 = null;
var count__6290_6385 = (0);
var i__6291_6386 = (0);
while(true){
if((i__6291_6386 < count__6290_6385)){
var vec__6292_6387 = cljs.core._nth.call(null,chunk__6289_6384,i__6291_6386);
var line_6388 = cljs.core.nth.call(null,vec__6292_6387,(0),null);
var cols_6389 = cljs.core.nth.call(null,vec__6292_6387,(1),null);
var seq__6295_6390 = cljs.core.seq.call(null,cols_6389);
var chunk__6296_6391 = null;
var count__6297_6392 = (0);
var i__6298_6393 = (0);
while(true){
if((i__6298_6393 < count__6297_6392)){
var vec__6299_6394 = cljs.core._nth.call(null,chunk__6296_6391,i__6298_6393);
var col_6395 = cljs.core.nth.call(null,vec__6299_6394,(0),null);
var infos_6396 = cljs.core.nth.call(null,vec__6299_6394,(1),null);
encode_cols.call(null,infos_6396,source_idx_6379,line_6388,col_6395);


var G__6397 = seq__6295_6390;
var G__6398 = chunk__6296_6391;
var G__6399 = count__6297_6392;
var G__6400 = (i__6298_6393 + (1));
seq__6295_6390 = G__6397;
chunk__6296_6391 = G__6398;
count__6297_6392 = G__6399;
i__6298_6393 = G__6400;
continue;
} else {
var temp__6753__auto___6401 = cljs.core.seq.call(null,seq__6295_6390);
if(temp__6753__auto___6401){
var seq__6295_6402__$1 = temp__6753__auto___6401;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6295_6402__$1)){
var c__4319__auto___6403 = cljs.core.chunk_first.call(null,seq__6295_6402__$1);
var G__6404 = cljs.core.chunk_rest.call(null,seq__6295_6402__$1);
var G__6405 = c__4319__auto___6403;
var G__6406 = cljs.core.count.call(null,c__4319__auto___6403);
var G__6407 = (0);
seq__6295_6390 = G__6404;
chunk__6296_6391 = G__6405;
count__6297_6392 = G__6406;
i__6298_6393 = G__6407;
continue;
} else {
var vec__6302_6408 = cljs.core.first.call(null,seq__6295_6402__$1);
var col_6409 = cljs.core.nth.call(null,vec__6302_6408,(0),null);
var infos_6410 = cljs.core.nth.call(null,vec__6302_6408,(1),null);
encode_cols.call(null,infos_6410,source_idx_6379,line_6388,col_6409);


var G__6411 = cljs.core.next.call(null,seq__6295_6402__$1);
var G__6412 = null;
var G__6413 = (0);
var G__6414 = (0);
seq__6295_6390 = G__6411;
chunk__6296_6391 = G__6412;
count__6297_6392 = G__6413;
i__6298_6393 = G__6414;
continue;
}
} else {
}
}
break;
}


var G__6415 = seq__6288_6383;
var G__6416 = chunk__6289_6384;
var G__6417 = count__6290_6385;
var G__6418 = (i__6291_6386 + (1));
seq__6288_6383 = G__6415;
chunk__6289_6384 = G__6416;
count__6290_6385 = G__6417;
i__6291_6386 = G__6418;
continue;
} else {
var temp__6753__auto___6419 = cljs.core.seq.call(null,seq__6288_6383);
if(temp__6753__auto___6419){
var seq__6288_6420__$1 = temp__6753__auto___6419;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6288_6420__$1)){
var c__4319__auto___6421 = cljs.core.chunk_first.call(null,seq__6288_6420__$1);
var G__6422 = cljs.core.chunk_rest.call(null,seq__6288_6420__$1);
var G__6423 = c__4319__auto___6421;
var G__6424 = cljs.core.count.call(null,c__4319__auto___6421);
var G__6425 = (0);
seq__6288_6383 = G__6422;
chunk__6289_6384 = G__6423;
count__6290_6385 = G__6424;
i__6291_6386 = G__6425;
continue;
} else {
var vec__6305_6426 = cljs.core.first.call(null,seq__6288_6420__$1);
var line_6427 = cljs.core.nth.call(null,vec__6305_6426,(0),null);
var cols_6428 = cljs.core.nth.call(null,vec__6305_6426,(1),null);
var seq__6308_6429 = cljs.core.seq.call(null,cols_6428);
var chunk__6309_6430 = null;
var count__6310_6431 = (0);
var i__6311_6432 = (0);
while(true){
if((i__6311_6432 < count__6310_6431)){
var vec__6312_6433 = cljs.core._nth.call(null,chunk__6309_6430,i__6311_6432);
var col_6434 = cljs.core.nth.call(null,vec__6312_6433,(0),null);
var infos_6435 = cljs.core.nth.call(null,vec__6312_6433,(1),null);
encode_cols.call(null,infos_6435,source_idx_6379,line_6427,col_6434);


var G__6436 = seq__6308_6429;
var G__6437 = chunk__6309_6430;
var G__6438 = count__6310_6431;
var G__6439 = (i__6311_6432 + (1));
seq__6308_6429 = G__6436;
chunk__6309_6430 = G__6437;
count__6310_6431 = G__6438;
i__6311_6432 = G__6439;
continue;
} else {
var temp__6753__auto___6440__$1 = cljs.core.seq.call(null,seq__6308_6429);
if(temp__6753__auto___6440__$1){
var seq__6308_6441__$1 = temp__6753__auto___6440__$1;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6308_6441__$1)){
var c__4319__auto___6442 = cljs.core.chunk_first.call(null,seq__6308_6441__$1);
var G__6443 = cljs.core.chunk_rest.call(null,seq__6308_6441__$1);
var G__6444 = c__4319__auto___6442;
var G__6445 = cljs.core.count.call(null,c__4319__auto___6442);
var G__6446 = (0);
seq__6308_6429 = G__6443;
chunk__6309_6430 = G__6444;
count__6310_6431 = G__6445;
i__6311_6432 = G__6446;
continue;
} else {
var vec__6315_6447 = cljs.core.first.call(null,seq__6308_6441__$1);
var col_6448 = cljs.core.nth.call(null,vec__6315_6447,(0),null);
var infos_6449 = cljs.core.nth.call(null,vec__6315_6447,(1),null);
encode_cols.call(null,infos_6449,source_idx_6379,line_6427,col_6448);


var G__6450 = cljs.core.next.call(null,seq__6308_6441__$1);
var G__6451 = null;
var G__6452 = (0);
var G__6453 = (0);
seq__6308_6429 = G__6450;
chunk__6309_6430 = G__6451;
count__6310_6431 = G__6452;
i__6311_6432 = G__6453;
continue;
}
} else {
}
}
break;
}


var G__6454 = cljs.core.next.call(null,seq__6288_6420__$1);
var G__6455 = null;
var G__6456 = (0);
var G__6457 = (0);
seq__6288_6383 = G__6454;
chunk__6289_6384 = G__6455;
count__6290_6385 = G__6456;
i__6291_6386 = G__6457;
continue;
}
} else {
}
}
break;
}


var G__6458 = seq__6278_6374;
var G__6459 = chunk__6279_6375;
var G__6460 = count__6280_6376;
var G__6461 = (i__6281_6377 + (1));
seq__6278_6374 = G__6458;
chunk__6279_6375 = G__6459;
count__6280_6376 = G__6460;
i__6281_6377 = G__6461;
continue;
} else {
var temp__6753__auto___6462 = cljs.core.seq.call(null,seq__6278_6374);
if(temp__6753__auto___6462){
var seq__6278_6463__$1 = temp__6753__auto___6462;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6278_6463__$1)){
var c__4319__auto___6464 = cljs.core.chunk_first.call(null,seq__6278_6463__$1);
var G__6465 = cljs.core.chunk_rest.call(null,seq__6278_6463__$1);
var G__6466 = c__4319__auto___6464;
var G__6467 = cljs.core.count.call(null,c__4319__auto___6464);
var G__6468 = (0);
seq__6278_6374 = G__6465;
chunk__6279_6375 = G__6466;
count__6280_6376 = G__6467;
i__6281_6377 = G__6468;
continue;
} else {
var vec__6318_6469 = cljs.core.first.call(null,seq__6278_6463__$1);
var source_idx_6470 = cljs.core.nth.call(null,vec__6318_6469,(0),null);
var vec__6321_6471 = cljs.core.nth.call(null,vec__6318_6469,(1),null);
var __6472 = cljs.core.nth.call(null,vec__6321_6471,(0),null);
var lines_6473__$1 = cljs.core.nth.call(null,vec__6321_6471,(1),null);
var seq__6324_6474 = cljs.core.seq.call(null,lines_6473__$1);
var chunk__6325_6475 = null;
var count__6326_6476 = (0);
var i__6327_6477 = (0);
while(true){
if((i__6327_6477 < count__6326_6476)){
var vec__6328_6478 = cljs.core._nth.call(null,chunk__6325_6475,i__6327_6477);
var line_6479 = cljs.core.nth.call(null,vec__6328_6478,(0),null);
var cols_6480 = cljs.core.nth.call(null,vec__6328_6478,(1),null);
var seq__6331_6481 = cljs.core.seq.call(null,cols_6480);
var chunk__6332_6482 = null;
var count__6333_6483 = (0);
var i__6334_6484 = (0);
while(true){
if((i__6334_6484 < count__6333_6483)){
var vec__6335_6485 = cljs.core._nth.call(null,chunk__6332_6482,i__6334_6484);
var col_6486 = cljs.core.nth.call(null,vec__6335_6485,(0),null);
var infos_6487 = cljs.core.nth.call(null,vec__6335_6485,(1),null);
encode_cols.call(null,infos_6487,source_idx_6470,line_6479,col_6486);


var G__6488 = seq__6331_6481;
var G__6489 = chunk__6332_6482;
var G__6490 = count__6333_6483;
var G__6491 = (i__6334_6484 + (1));
seq__6331_6481 = G__6488;
chunk__6332_6482 = G__6489;
count__6333_6483 = G__6490;
i__6334_6484 = G__6491;
continue;
} else {
var temp__6753__auto___6492__$1 = cljs.core.seq.call(null,seq__6331_6481);
if(temp__6753__auto___6492__$1){
var seq__6331_6493__$1 = temp__6753__auto___6492__$1;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6331_6493__$1)){
var c__4319__auto___6494 = cljs.core.chunk_first.call(null,seq__6331_6493__$1);
var G__6495 = cljs.core.chunk_rest.call(null,seq__6331_6493__$1);
var G__6496 = c__4319__auto___6494;
var G__6497 = cljs.core.count.call(null,c__4319__auto___6494);
var G__6498 = (0);
seq__6331_6481 = G__6495;
chunk__6332_6482 = G__6496;
count__6333_6483 = G__6497;
i__6334_6484 = G__6498;
continue;
} else {
var vec__6338_6499 = cljs.core.first.call(null,seq__6331_6493__$1);
var col_6500 = cljs.core.nth.call(null,vec__6338_6499,(0),null);
var infos_6501 = cljs.core.nth.call(null,vec__6338_6499,(1),null);
encode_cols.call(null,infos_6501,source_idx_6470,line_6479,col_6500);


var G__6502 = cljs.core.next.call(null,seq__6331_6493__$1);
var G__6503 = null;
var G__6504 = (0);
var G__6505 = (0);
seq__6331_6481 = G__6502;
chunk__6332_6482 = G__6503;
count__6333_6483 = G__6504;
i__6334_6484 = G__6505;
continue;
}
} else {
}
}
break;
}


var G__6506 = seq__6324_6474;
var G__6507 = chunk__6325_6475;
var G__6508 = count__6326_6476;
var G__6509 = (i__6327_6477 + (1));
seq__6324_6474 = G__6506;
chunk__6325_6475 = G__6507;
count__6326_6476 = G__6508;
i__6327_6477 = G__6509;
continue;
} else {
var temp__6753__auto___6510__$1 = cljs.core.seq.call(null,seq__6324_6474);
if(temp__6753__auto___6510__$1){
var seq__6324_6511__$1 = temp__6753__auto___6510__$1;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6324_6511__$1)){
var c__4319__auto___6512 = cljs.core.chunk_first.call(null,seq__6324_6511__$1);
var G__6513 = cljs.core.chunk_rest.call(null,seq__6324_6511__$1);
var G__6514 = c__4319__auto___6512;
var G__6515 = cljs.core.count.call(null,c__4319__auto___6512);
var G__6516 = (0);
seq__6324_6474 = G__6513;
chunk__6325_6475 = G__6514;
count__6326_6476 = G__6515;
i__6327_6477 = G__6516;
continue;
} else {
var vec__6341_6517 = cljs.core.first.call(null,seq__6324_6511__$1);
var line_6518 = cljs.core.nth.call(null,vec__6341_6517,(0),null);
var cols_6519 = cljs.core.nth.call(null,vec__6341_6517,(1),null);
var seq__6344_6520 = cljs.core.seq.call(null,cols_6519);
var chunk__6345_6521 = null;
var count__6346_6522 = (0);
var i__6347_6523 = (0);
while(true){
if((i__6347_6523 < count__6346_6522)){
var vec__6348_6524 = cljs.core._nth.call(null,chunk__6345_6521,i__6347_6523);
var col_6525 = cljs.core.nth.call(null,vec__6348_6524,(0),null);
var infos_6526 = cljs.core.nth.call(null,vec__6348_6524,(1),null);
encode_cols.call(null,infos_6526,source_idx_6470,line_6518,col_6525);


var G__6527 = seq__6344_6520;
var G__6528 = chunk__6345_6521;
var G__6529 = count__6346_6522;
var G__6530 = (i__6347_6523 + (1));
seq__6344_6520 = G__6527;
chunk__6345_6521 = G__6528;
count__6346_6522 = G__6529;
i__6347_6523 = G__6530;
continue;
} else {
var temp__6753__auto___6531__$2 = cljs.core.seq.call(null,seq__6344_6520);
if(temp__6753__auto___6531__$2){
var seq__6344_6532__$1 = temp__6753__auto___6531__$2;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6344_6532__$1)){
var c__4319__auto___6533 = cljs.core.chunk_first.call(null,seq__6344_6532__$1);
var G__6534 = cljs.core.chunk_rest.call(null,seq__6344_6532__$1);
var G__6535 = c__4319__auto___6533;
var G__6536 = cljs.core.count.call(null,c__4319__auto___6533);
var G__6537 = (0);
seq__6344_6520 = G__6534;
chunk__6345_6521 = G__6535;
count__6346_6522 = G__6536;
i__6347_6523 = G__6537;
continue;
} else {
var vec__6351_6538 = cljs.core.first.call(null,seq__6344_6532__$1);
var col_6539 = cljs.core.nth.call(null,vec__6351_6538,(0),null);
var infos_6540 = cljs.core.nth.call(null,vec__6351_6538,(1),null);
encode_cols.call(null,infos_6540,source_idx_6470,line_6518,col_6539);


var G__6541 = cljs.core.next.call(null,seq__6344_6532__$1);
var G__6542 = null;
var G__6543 = (0);
var G__6544 = (0);
seq__6344_6520 = G__6541;
chunk__6345_6521 = G__6542;
count__6346_6522 = G__6543;
i__6347_6523 = G__6544;
continue;
}
} else {
}
}
break;
}


var G__6545 = cljs.core.next.call(null,seq__6324_6511__$1);
var G__6546 = null;
var G__6547 = (0);
var G__6548 = (0);
seq__6324_6474 = G__6545;
chunk__6325_6475 = G__6546;
count__6326_6476 = G__6547;
i__6327_6477 = G__6548;
continue;
}
} else {
}
}
break;
}


var G__6549 = cljs.core.next.call(null,seq__6278_6463__$1);
var G__6550 = null;
var G__6551 = (0);
var G__6552 = (0);
seq__6278_6374 = G__6549;
chunk__6279_6375 = G__6550;
count__6280_6376 = G__6551;
i__6281_6377 = G__6552;
continue;
}
} else {
}
}
break;
}

var source_map_file_contents = (function (){var G__6354 = ({"version": (3), "file": new cljs.core.Keyword(null,"file","file",-1269645878).cljs$core$IFn$_invoke$arity$1(opts), "sources": (function (){var paths = cljs.core.keys.call(null,m);
var f = cljs.core.comp.call(null,((new cljs.core.Keyword(null,"source-map-timestamp","source-map-timestamp",1973015633).cljs$core$IFn$_invoke$arity$1(opts) === true)?((function (paths,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols){
return (function (p1__6271_SHARP_){
return [cljs.core.str.cljs$core$IFn$_invoke$arity$1(p1__6271_SHARP_),"?rel=",cljs.core.str.cljs$core$IFn$_invoke$arity$1((new Date()).valueOf())].join('');
});})(paths,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols))
:cljs.core.identity),((function (paths,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols){
return (function (p1__6272_SHARP_){
return cljs.core.last.call(null,clojure.string.split.call(null,p1__6272_SHARP_,/\//));
});})(paths,lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols))
);
return cljs.core.into_array.call(null,cljs.core.map.call(null,f,paths));
})(), "lineCount": new cljs.core.Keyword(null,"lines","lines",-700165781).cljs$core$IFn$_invoke$arity$1(opts), "mappings": clojure.string.join.call(null,";",cljs.core.map.call(null,((function (lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols){
return (function (p1__6273_SHARP_){
return clojure.string.join.call(null,",",p1__6273_SHARP_);
});})(lines,names__GT_idx,name_idx,preamble_lines,info__GT_segv,encode_cols))
,cljs.source_map.lines__GT_segs.call(null,cljs.core.concat.call(null,preamble_lines,cljs.core.deref.call(null,lines))))), "names": cljs.core.into_array.call(null,cljs.core.map.call(null,clojure.set.map_invert.call(null,cljs.core.deref.call(null,names__GT_idx)),cljs.core.range.call(null,cljs.core.count.call(null,cljs.core.deref.call(null,names__GT_idx)))))});
if(cljs.core.truth_(new cljs.core.Keyword(null,"sources-content","sources-content",1729970239).cljs$core$IFn$_invoke$arity$1(opts))){
var G__6355 = G__6354;
goog.object.set(G__6355,"sourcesContent",cljs.core.into_array.call(null,new cljs.core.Keyword(null,"sources-content","sources-content",1729970239).cljs$core$IFn$_invoke$arity$1(opts)));

return G__6355;
} else {
return G__6354;
}
})();
return JSON.stringify(source_map_file_contents);
});
/**
 * Merge an internal source map representation of a single
 * ClojureScript file mapping original to generated with a
 * second source map mapping original JS to generated JS.
 * The is to support source maps that work through multiple
 * compilation steps like Google Closure optimization passes.
 */
cljs.source_map.merge_source_maps = (function cljs$source_map$merge_source_maps(cljs_map,js_map){
var line_map_seq = cljs.core.seq.call(null,cljs_map);
var new_lines = cljs.core.sorted_map.call(null);
while(true){
if(line_map_seq){
var vec__6553 = cljs.core.first.call(null,line_map_seq);
var line = cljs.core.nth.call(null,vec__6553,(0),null);
var col_map = cljs.core.nth.call(null,vec__6553,(1),null);
var new_cols = (function (){var col_map_seq = cljs.core.seq.call(null,col_map);
var new_cols = cljs.core.sorted_map.call(null);
while(true){
if(col_map_seq){
var vec__6556 = cljs.core.first.call(null,col_map_seq);
var col = cljs.core.nth.call(null,vec__6556,(0),null);
var infos = cljs.core.nth.call(null,vec__6556,(1),null);
var G__6562 = cljs.core.next.call(null,col_map_seq);
var G__6563 = cljs.core.assoc.call(null,new_cols,col,cljs.core.reduce.call(null,((function (col_map_seq,new_cols,line_map_seq,new_lines,vec__6556,col,infos,vec__6553,line,col_map){
return (function (v,p__6559){
var map__6560 = p__6559;
var map__6560__$1 = ((((!((map__6560 == null)))?(((((map__6560.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__6560.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__6560):map__6560);
var gline = cljs.core.get.call(null,map__6560__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol = cljs.core.get.call(null,map__6560__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
return cljs.core.into.call(null,v,cljs.core.get_in.call(null,js_map,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline,gcol], null)));
});})(col_map_seq,new_cols,line_map_seq,new_lines,vec__6556,col,infos,vec__6553,line,col_map))
,cljs.core.PersistentVector.EMPTY,infos));
col_map_seq = G__6562;
new_cols = G__6563;
continue;
} else {
return new_cols;
}
break;
}
})();
var G__6564 = cljs.core.next.call(null,line_map_seq);
var G__6565 = cljs.core.assoc.call(null,new_lines,line,new_cols);
line_map_seq = G__6564;
new_lines = G__6565;
continue;
} else {
return new_lines;
}
break;
}
});
/**
 * Given a ClojureScript to JavaScript source map, invert it. Useful when
 * mapping JavaScript stack traces when environment support is unavailable.
 */
cljs.source_map.invert_reverse_map = (function cljs$source_map$invert_reverse_map(reverse_map){
var inverted = cljs.core.atom.call(null,cljs.core.sorted_map.call(null));
var seq__6566_6628 = cljs.core.seq.call(null,reverse_map);
var chunk__6567_6629 = null;
var count__6568_6630 = (0);
var i__6569_6631 = (0);
while(true){
if((i__6569_6631 < count__6568_6630)){
var vec__6570_6632 = cljs.core._nth.call(null,chunk__6567_6629,i__6569_6631);
var line_6633 = cljs.core.nth.call(null,vec__6570_6632,(0),null);
var columns_6634 = cljs.core.nth.call(null,vec__6570_6632,(1),null);
var seq__6573_6635 = cljs.core.seq.call(null,columns_6634);
var chunk__6574_6636 = null;
var count__6575_6637 = (0);
var i__6576_6638 = (0);
while(true){
if((i__6576_6638 < count__6575_6637)){
var vec__6577_6639 = cljs.core._nth.call(null,chunk__6574_6636,i__6576_6638);
var column_6640 = cljs.core.nth.call(null,vec__6577_6639,(0),null);
var column_info_6641 = cljs.core.nth.call(null,vec__6577_6639,(1),null);
var seq__6580_6642 = cljs.core.seq.call(null,column_info_6641);
var chunk__6581_6643 = null;
var count__6582_6644 = (0);
var i__6583_6645 = (0);
while(true){
if((i__6583_6645 < count__6582_6644)){
var map__6584_6646 = cljs.core._nth.call(null,chunk__6581_6643,i__6583_6645);
var map__6584_6647__$1 = ((((!((map__6584_6646 == null)))?(((((map__6584_6646.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__6584_6646.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__6584_6646):map__6584_6646);
var gline_6648 = cljs.core.get.call(null,map__6584_6647__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_6649 = cljs.core.get.call(null,map__6584_6647__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_6650 = cljs.core.get.call(null,map__6584_6647__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_6648], null),cljs.core.fnil.call(null,((function (seq__6580_6642,chunk__6581_6643,count__6582_6644,i__6583_6645,seq__6573_6635,chunk__6574_6636,count__6575_6637,i__6576_6638,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6584_6646,map__6584_6647__$1,gline_6648,gcol_6649,name_6650,vec__6577_6639,column_6640,column_info_6641,vec__6570_6632,line_6633,columns_6634,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_6649], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_6633,new cljs.core.Keyword(null,"col","col",-1959363084),column_6640,new cljs.core.Keyword(null,"name","name",1843675177),name_6650], null));
});})(seq__6580_6642,chunk__6581_6643,count__6582_6644,i__6583_6645,seq__6573_6635,chunk__6574_6636,count__6575_6637,i__6576_6638,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6584_6646,map__6584_6647__$1,gline_6648,gcol_6649,name_6650,vec__6577_6639,column_6640,column_info_6641,vec__6570_6632,line_6633,columns_6634,inverted))
,cljs.core.sorted_map.call(null)));


var G__6651 = seq__6580_6642;
var G__6652 = chunk__6581_6643;
var G__6653 = count__6582_6644;
var G__6654 = (i__6583_6645 + (1));
seq__6580_6642 = G__6651;
chunk__6581_6643 = G__6652;
count__6582_6644 = G__6653;
i__6583_6645 = G__6654;
continue;
} else {
var temp__6753__auto___6655 = cljs.core.seq.call(null,seq__6580_6642);
if(temp__6753__auto___6655){
var seq__6580_6656__$1 = temp__6753__auto___6655;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6580_6656__$1)){
var c__4319__auto___6657 = cljs.core.chunk_first.call(null,seq__6580_6656__$1);
var G__6658 = cljs.core.chunk_rest.call(null,seq__6580_6656__$1);
var G__6659 = c__4319__auto___6657;
var G__6660 = cljs.core.count.call(null,c__4319__auto___6657);
var G__6661 = (0);
seq__6580_6642 = G__6658;
chunk__6581_6643 = G__6659;
count__6582_6644 = G__6660;
i__6583_6645 = G__6661;
continue;
} else {
var map__6586_6662 = cljs.core.first.call(null,seq__6580_6656__$1);
var map__6586_6663__$1 = ((((!((map__6586_6662 == null)))?(((((map__6586_6662.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__6586_6662.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__6586_6662):map__6586_6662);
var gline_6664 = cljs.core.get.call(null,map__6586_6663__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_6665 = cljs.core.get.call(null,map__6586_6663__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_6666 = cljs.core.get.call(null,map__6586_6663__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_6664], null),cljs.core.fnil.call(null,((function (seq__6580_6642,chunk__6581_6643,count__6582_6644,i__6583_6645,seq__6573_6635,chunk__6574_6636,count__6575_6637,i__6576_6638,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6586_6662,map__6586_6663__$1,gline_6664,gcol_6665,name_6666,seq__6580_6656__$1,temp__6753__auto___6655,vec__6577_6639,column_6640,column_info_6641,vec__6570_6632,line_6633,columns_6634,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_6665], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_6633,new cljs.core.Keyword(null,"col","col",-1959363084),column_6640,new cljs.core.Keyword(null,"name","name",1843675177),name_6666], null));
});})(seq__6580_6642,chunk__6581_6643,count__6582_6644,i__6583_6645,seq__6573_6635,chunk__6574_6636,count__6575_6637,i__6576_6638,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6586_6662,map__6586_6663__$1,gline_6664,gcol_6665,name_6666,seq__6580_6656__$1,temp__6753__auto___6655,vec__6577_6639,column_6640,column_info_6641,vec__6570_6632,line_6633,columns_6634,inverted))
,cljs.core.sorted_map.call(null)));


var G__6667 = cljs.core.next.call(null,seq__6580_6656__$1);
var G__6668 = null;
var G__6669 = (0);
var G__6670 = (0);
seq__6580_6642 = G__6667;
chunk__6581_6643 = G__6668;
count__6582_6644 = G__6669;
i__6583_6645 = G__6670;
continue;
}
} else {
}
}
break;
}


var G__6671 = seq__6573_6635;
var G__6672 = chunk__6574_6636;
var G__6673 = count__6575_6637;
var G__6674 = (i__6576_6638 + (1));
seq__6573_6635 = G__6671;
chunk__6574_6636 = G__6672;
count__6575_6637 = G__6673;
i__6576_6638 = G__6674;
continue;
} else {
var temp__6753__auto___6675 = cljs.core.seq.call(null,seq__6573_6635);
if(temp__6753__auto___6675){
var seq__6573_6676__$1 = temp__6753__auto___6675;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6573_6676__$1)){
var c__4319__auto___6677 = cljs.core.chunk_first.call(null,seq__6573_6676__$1);
var G__6678 = cljs.core.chunk_rest.call(null,seq__6573_6676__$1);
var G__6679 = c__4319__auto___6677;
var G__6680 = cljs.core.count.call(null,c__4319__auto___6677);
var G__6681 = (0);
seq__6573_6635 = G__6678;
chunk__6574_6636 = G__6679;
count__6575_6637 = G__6680;
i__6576_6638 = G__6681;
continue;
} else {
var vec__6588_6682 = cljs.core.first.call(null,seq__6573_6676__$1);
var column_6683 = cljs.core.nth.call(null,vec__6588_6682,(0),null);
var column_info_6684 = cljs.core.nth.call(null,vec__6588_6682,(1),null);
var seq__6591_6685 = cljs.core.seq.call(null,column_info_6684);
var chunk__6592_6686 = null;
var count__6593_6687 = (0);
var i__6594_6688 = (0);
while(true){
if((i__6594_6688 < count__6593_6687)){
var map__6595_6689 = cljs.core._nth.call(null,chunk__6592_6686,i__6594_6688);
var map__6595_6690__$1 = ((((!((map__6595_6689 == null)))?(((((map__6595_6689.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__6595_6689.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__6595_6689):map__6595_6689);
var gline_6691 = cljs.core.get.call(null,map__6595_6690__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_6692 = cljs.core.get.call(null,map__6595_6690__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_6693 = cljs.core.get.call(null,map__6595_6690__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_6691], null),cljs.core.fnil.call(null,((function (seq__6591_6685,chunk__6592_6686,count__6593_6687,i__6594_6688,seq__6573_6635,chunk__6574_6636,count__6575_6637,i__6576_6638,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6595_6689,map__6595_6690__$1,gline_6691,gcol_6692,name_6693,vec__6588_6682,column_6683,column_info_6684,seq__6573_6676__$1,temp__6753__auto___6675,vec__6570_6632,line_6633,columns_6634,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_6692], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_6633,new cljs.core.Keyword(null,"col","col",-1959363084),column_6683,new cljs.core.Keyword(null,"name","name",1843675177),name_6693], null));
});})(seq__6591_6685,chunk__6592_6686,count__6593_6687,i__6594_6688,seq__6573_6635,chunk__6574_6636,count__6575_6637,i__6576_6638,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6595_6689,map__6595_6690__$1,gline_6691,gcol_6692,name_6693,vec__6588_6682,column_6683,column_info_6684,seq__6573_6676__$1,temp__6753__auto___6675,vec__6570_6632,line_6633,columns_6634,inverted))
,cljs.core.sorted_map.call(null)));


var G__6694 = seq__6591_6685;
var G__6695 = chunk__6592_6686;
var G__6696 = count__6593_6687;
var G__6697 = (i__6594_6688 + (1));
seq__6591_6685 = G__6694;
chunk__6592_6686 = G__6695;
count__6593_6687 = G__6696;
i__6594_6688 = G__6697;
continue;
} else {
var temp__6753__auto___6698__$1 = cljs.core.seq.call(null,seq__6591_6685);
if(temp__6753__auto___6698__$1){
var seq__6591_6699__$1 = temp__6753__auto___6698__$1;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6591_6699__$1)){
var c__4319__auto___6700 = cljs.core.chunk_first.call(null,seq__6591_6699__$1);
var G__6701 = cljs.core.chunk_rest.call(null,seq__6591_6699__$1);
var G__6702 = c__4319__auto___6700;
var G__6703 = cljs.core.count.call(null,c__4319__auto___6700);
var G__6704 = (0);
seq__6591_6685 = G__6701;
chunk__6592_6686 = G__6702;
count__6593_6687 = G__6703;
i__6594_6688 = G__6704;
continue;
} else {
var map__6597_6705 = cljs.core.first.call(null,seq__6591_6699__$1);
var map__6597_6706__$1 = ((((!((map__6597_6705 == null)))?(((((map__6597_6705.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__6597_6705.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__6597_6705):map__6597_6705);
var gline_6707 = cljs.core.get.call(null,map__6597_6706__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_6708 = cljs.core.get.call(null,map__6597_6706__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_6709 = cljs.core.get.call(null,map__6597_6706__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_6707], null),cljs.core.fnil.call(null,((function (seq__6591_6685,chunk__6592_6686,count__6593_6687,i__6594_6688,seq__6573_6635,chunk__6574_6636,count__6575_6637,i__6576_6638,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6597_6705,map__6597_6706__$1,gline_6707,gcol_6708,name_6709,seq__6591_6699__$1,temp__6753__auto___6698__$1,vec__6588_6682,column_6683,column_info_6684,seq__6573_6676__$1,temp__6753__auto___6675,vec__6570_6632,line_6633,columns_6634,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_6708], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_6633,new cljs.core.Keyword(null,"col","col",-1959363084),column_6683,new cljs.core.Keyword(null,"name","name",1843675177),name_6709], null));
});})(seq__6591_6685,chunk__6592_6686,count__6593_6687,i__6594_6688,seq__6573_6635,chunk__6574_6636,count__6575_6637,i__6576_6638,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6597_6705,map__6597_6706__$1,gline_6707,gcol_6708,name_6709,seq__6591_6699__$1,temp__6753__auto___6698__$1,vec__6588_6682,column_6683,column_info_6684,seq__6573_6676__$1,temp__6753__auto___6675,vec__6570_6632,line_6633,columns_6634,inverted))
,cljs.core.sorted_map.call(null)));


var G__6710 = cljs.core.next.call(null,seq__6591_6699__$1);
var G__6711 = null;
var G__6712 = (0);
var G__6713 = (0);
seq__6591_6685 = G__6710;
chunk__6592_6686 = G__6711;
count__6593_6687 = G__6712;
i__6594_6688 = G__6713;
continue;
}
} else {
}
}
break;
}


var G__6714 = cljs.core.next.call(null,seq__6573_6676__$1);
var G__6715 = null;
var G__6716 = (0);
var G__6717 = (0);
seq__6573_6635 = G__6714;
chunk__6574_6636 = G__6715;
count__6575_6637 = G__6716;
i__6576_6638 = G__6717;
continue;
}
} else {
}
}
break;
}


var G__6718 = seq__6566_6628;
var G__6719 = chunk__6567_6629;
var G__6720 = count__6568_6630;
var G__6721 = (i__6569_6631 + (1));
seq__6566_6628 = G__6718;
chunk__6567_6629 = G__6719;
count__6568_6630 = G__6720;
i__6569_6631 = G__6721;
continue;
} else {
var temp__6753__auto___6722 = cljs.core.seq.call(null,seq__6566_6628);
if(temp__6753__auto___6722){
var seq__6566_6723__$1 = temp__6753__auto___6722;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6566_6723__$1)){
var c__4319__auto___6724 = cljs.core.chunk_first.call(null,seq__6566_6723__$1);
var G__6725 = cljs.core.chunk_rest.call(null,seq__6566_6723__$1);
var G__6726 = c__4319__auto___6724;
var G__6727 = cljs.core.count.call(null,c__4319__auto___6724);
var G__6728 = (0);
seq__6566_6628 = G__6725;
chunk__6567_6629 = G__6726;
count__6568_6630 = G__6727;
i__6569_6631 = G__6728;
continue;
} else {
var vec__6599_6729 = cljs.core.first.call(null,seq__6566_6723__$1);
var line_6730 = cljs.core.nth.call(null,vec__6599_6729,(0),null);
var columns_6731 = cljs.core.nth.call(null,vec__6599_6729,(1),null);
var seq__6602_6732 = cljs.core.seq.call(null,columns_6731);
var chunk__6603_6733 = null;
var count__6604_6734 = (0);
var i__6605_6735 = (0);
while(true){
if((i__6605_6735 < count__6604_6734)){
var vec__6606_6736 = cljs.core._nth.call(null,chunk__6603_6733,i__6605_6735);
var column_6737 = cljs.core.nth.call(null,vec__6606_6736,(0),null);
var column_info_6738 = cljs.core.nth.call(null,vec__6606_6736,(1),null);
var seq__6609_6739 = cljs.core.seq.call(null,column_info_6738);
var chunk__6610_6740 = null;
var count__6611_6741 = (0);
var i__6612_6742 = (0);
while(true){
if((i__6612_6742 < count__6611_6741)){
var map__6613_6743 = cljs.core._nth.call(null,chunk__6610_6740,i__6612_6742);
var map__6613_6744__$1 = ((((!((map__6613_6743 == null)))?(((((map__6613_6743.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__6613_6743.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__6613_6743):map__6613_6743);
var gline_6745 = cljs.core.get.call(null,map__6613_6744__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_6746 = cljs.core.get.call(null,map__6613_6744__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_6747 = cljs.core.get.call(null,map__6613_6744__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_6745], null),cljs.core.fnil.call(null,((function (seq__6609_6739,chunk__6610_6740,count__6611_6741,i__6612_6742,seq__6602_6732,chunk__6603_6733,count__6604_6734,i__6605_6735,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6613_6743,map__6613_6744__$1,gline_6745,gcol_6746,name_6747,vec__6606_6736,column_6737,column_info_6738,vec__6599_6729,line_6730,columns_6731,seq__6566_6723__$1,temp__6753__auto___6722,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_6746], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_6730,new cljs.core.Keyword(null,"col","col",-1959363084),column_6737,new cljs.core.Keyword(null,"name","name",1843675177),name_6747], null));
});})(seq__6609_6739,chunk__6610_6740,count__6611_6741,i__6612_6742,seq__6602_6732,chunk__6603_6733,count__6604_6734,i__6605_6735,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6613_6743,map__6613_6744__$1,gline_6745,gcol_6746,name_6747,vec__6606_6736,column_6737,column_info_6738,vec__6599_6729,line_6730,columns_6731,seq__6566_6723__$1,temp__6753__auto___6722,inverted))
,cljs.core.sorted_map.call(null)));


var G__6748 = seq__6609_6739;
var G__6749 = chunk__6610_6740;
var G__6750 = count__6611_6741;
var G__6751 = (i__6612_6742 + (1));
seq__6609_6739 = G__6748;
chunk__6610_6740 = G__6749;
count__6611_6741 = G__6750;
i__6612_6742 = G__6751;
continue;
} else {
var temp__6753__auto___6752__$1 = cljs.core.seq.call(null,seq__6609_6739);
if(temp__6753__auto___6752__$1){
var seq__6609_6753__$1 = temp__6753__auto___6752__$1;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6609_6753__$1)){
var c__4319__auto___6754 = cljs.core.chunk_first.call(null,seq__6609_6753__$1);
var G__6755 = cljs.core.chunk_rest.call(null,seq__6609_6753__$1);
var G__6756 = c__4319__auto___6754;
var G__6757 = cljs.core.count.call(null,c__4319__auto___6754);
var G__6758 = (0);
seq__6609_6739 = G__6755;
chunk__6610_6740 = G__6756;
count__6611_6741 = G__6757;
i__6612_6742 = G__6758;
continue;
} else {
var map__6615_6759 = cljs.core.first.call(null,seq__6609_6753__$1);
var map__6615_6760__$1 = ((((!((map__6615_6759 == null)))?(((((map__6615_6759.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__6615_6759.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__6615_6759):map__6615_6759);
var gline_6761 = cljs.core.get.call(null,map__6615_6760__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_6762 = cljs.core.get.call(null,map__6615_6760__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_6763 = cljs.core.get.call(null,map__6615_6760__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_6761], null),cljs.core.fnil.call(null,((function (seq__6609_6739,chunk__6610_6740,count__6611_6741,i__6612_6742,seq__6602_6732,chunk__6603_6733,count__6604_6734,i__6605_6735,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6615_6759,map__6615_6760__$1,gline_6761,gcol_6762,name_6763,seq__6609_6753__$1,temp__6753__auto___6752__$1,vec__6606_6736,column_6737,column_info_6738,vec__6599_6729,line_6730,columns_6731,seq__6566_6723__$1,temp__6753__auto___6722,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_6762], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_6730,new cljs.core.Keyword(null,"col","col",-1959363084),column_6737,new cljs.core.Keyword(null,"name","name",1843675177),name_6763], null));
});})(seq__6609_6739,chunk__6610_6740,count__6611_6741,i__6612_6742,seq__6602_6732,chunk__6603_6733,count__6604_6734,i__6605_6735,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6615_6759,map__6615_6760__$1,gline_6761,gcol_6762,name_6763,seq__6609_6753__$1,temp__6753__auto___6752__$1,vec__6606_6736,column_6737,column_info_6738,vec__6599_6729,line_6730,columns_6731,seq__6566_6723__$1,temp__6753__auto___6722,inverted))
,cljs.core.sorted_map.call(null)));


var G__6764 = cljs.core.next.call(null,seq__6609_6753__$1);
var G__6765 = null;
var G__6766 = (0);
var G__6767 = (0);
seq__6609_6739 = G__6764;
chunk__6610_6740 = G__6765;
count__6611_6741 = G__6766;
i__6612_6742 = G__6767;
continue;
}
} else {
}
}
break;
}


var G__6768 = seq__6602_6732;
var G__6769 = chunk__6603_6733;
var G__6770 = count__6604_6734;
var G__6771 = (i__6605_6735 + (1));
seq__6602_6732 = G__6768;
chunk__6603_6733 = G__6769;
count__6604_6734 = G__6770;
i__6605_6735 = G__6771;
continue;
} else {
var temp__6753__auto___6772__$1 = cljs.core.seq.call(null,seq__6602_6732);
if(temp__6753__auto___6772__$1){
var seq__6602_6773__$1 = temp__6753__auto___6772__$1;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6602_6773__$1)){
var c__4319__auto___6774 = cljs.core.chunk_first.call(null,seq__6602_6773__$1);
var G__6775 = cljs.core.chunk_rest.call(null,seq__6602_6773__$1);
var G__6776 = c__4319__auto___6774;
var G__6777 = cljs.core.count.call(null,c__4319__auto___6774);
var G__6778 = (0);
seq__6602_6732 = G__6775;
chunk__6603_6733 = G__6776;
count__6604_6734 = G__6777;
i__6605_6735 = G__6778;
continue;
} else {
var vec__6617_6779 = cljs.core.first.call(null,seq__6602_6773__$1);
var column_6780 = cljs.core.nth.call(null,vec__6617_6779,(0),null);
var column_info_6781 = cljs.core.nth.call(null,vec__6617_6779,(1),null);
var seq__6620_6782 = cljs.core.seq.call(null,column_info_6781);
var chunk__6621_6783 = null;
var count__6622_6784 = (0);
var i__6623_6785 = (0);
while(true){
if((i__6623_6785 < count__6622_6784)){
var map__6624_6786 = cljs.core._nth.call(null,chunk__6621_6783,i__6623_6785);
var map__6624_6787__$1 = ((((!((map__6624_6786 == null)))?(((((map__6624_6786.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__6624_6786.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__6624_6786):map__6624_6786);
var gline_6788 = cljs.core.get.call(null,map__6624_6787__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_6789 = cljs.core.get.call(null,map__6624_6787__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_6790 = cljs.core.get.call(null,map__6624_6787__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_6788], null),cljs.core.fnil.call(null,((function (seq__6620_6782,chunk__6621_6783,count__6622_6784,i__6623_6785,seq__6602_6732,chunk__6603_6733,count__6604_6734,i__6605_6735,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6624_6786,map__6624_6787__$1,gline_6788,gcol_6789,name_6790,vec__6617_6779,column_6780,column_info_6781,seq__6602_6773__$1,temp__6753__auto___6772__$1,vec__6599_6729,line_6730,columns_6731,seq__6566_6723__$1,temp__6753__auto___6722,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_6789], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_6730,new cljs.core.Keyword(null,"col","col",-1959363084),column_6780,new cljs.core.Keyword(null,"name","name",1843675177),name_6790], null));
});})(seq__6620_6782,chunk__6621_6783,count__6622_6784,i__6623_6785,seq__6602_6732,chunk__6603_6733,count__6604_6734,i__6605_6735,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6624_6786,map__6624_6787__$1,gline_6788,gcol_6789,name_6790,vec__6617_6779,column_6780,column_info_6781,seq__6602_6773__$1,temp__6753__auto___6772__$1,vec__6599_6729,line_6730,columns_6731,seq__6566_6723__$1,temp__6753__auto___6722,inverted))
,cljs.core.sorted_map.call(null)));


var G__6791 = seq__6620_6782;
var G__6792 = chunk__6621_6783;
var G__6793 = count__6622_6784;
var G__6794 = (i__6623_6785 + (1));
seq__6620_6782 = G__6791;
chunk__6621_6783 = G__6792;
count__6622_6784 = G__6793;
i__6623_6785 = G__6794;
continue;
} else {
var temp__6753__auto___6795__$2 = cljs.core.seq.call(null,seq__6620_6782);
if(temp__6753__auto___6795__$2){
var seq__6620_6796__$1 = temp__6753__auto___6795__$2;
if(cljs.core.chunked_seq_QMARK_.call(null,seq__6620_6796__$1)){
var c__4319__auto___6797 = cljs.core.chunk_first.call(null,seq__6620_6796__$1);
var G__6798 = cljs.core.chunk_rest.call(null,seq__6620_6796__$1);
var G__6799 = c__4319__auto___6797;
var G__6800 = cljs.core.count.call(null,c__4319__auto___6797);
var G__6801 = (0);
seq__6620_6782 = G__6798;
chunk__6621_6783 = G__6799;
count__6622_6784 = G__6800;
i__6623_6785 = G__6801;
continue;
} else {
var map__6626_6802 = cljs.core.first.call(null,seq__6620_6796__$1);
var map__6626_6803__$1 = ((((!((map__6626_6802 == null)))?(((((map__6626_6802.cljs$lang$protocol_mask$partition0$ & (64))) || ((cljs.core.PROTOCOL_SENTINEL === map__6626_6802.cljs$core$ISeq$))))?true:false):false))?cljs.core.apply.call(null,cljs.core.hash_map,map__6626_6802):map__6626_6802);
var gline_6804 = cljs.core.get.call(null,map__6626_6803__$1,new cljs.core.Keyword(null,"gline","gline",-1086242431));
var gcol_6805 = cljs.core.get.call(null,map__6626_6803__$1,new cljs.core.Keyword(null,"gcol","gcol",309250807));
var name_6806 = cljs.core.get.call(null,map__6626_6803__$1,new cljs.core.Keyword(null,"name","name",1843675177));
cljs.core.swap_BANG_.call(null,inverted,cljs.core.update_in,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gline_6804], null),cljs.core.fnil.call(null,((function (seq__6620_6782,chunk__6621_6783,count__6622_6784,i__6623_6785,seq__6602_6732,chunk__6603_6733,count__6604_6734,i__6605_6735,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6626_6802,map__6626_6803__$1,gline_6804,gcol_6805,name_6806,seq__6620_6796__$1,temp__6753__auto___6795__$2,vec__6617_6779,column_6780,column_info_6781,seq__6602_6773__$1,temp__6753__auto___6772__$1,vec__6599_6729,line_6730,columns_6731,seq__6566_6723__$1,temp__6753__auto___6722,inverted){
return (function (columns__$1){
return cljs.core.update_in.call(null,columns__$1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [gcol_6805], null),cljs.core.fnil.call(null,cljs.core.conj,cljs.core.PersistentVector.EMPTY),new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"line","line",212345235),line_6730,new cljs.core.Keyword(null,"col","col",-1959363084),column_6780,new cljs.core.Keyword(null,"name","name",1843675177),name_6806], null));
});})(seq__6620_6782,chunk__6621_6783,count__6622_6784,i__6623_6785,seq__6602_6732,chunk__6603_6733,count__6604_6734,i__6605_6735,seq__6566_6628,chunk__6567_6629,count__6568_6630,i__6569_6631,map__6626_6802,map__6626_6803__$1,gline_6804,gcol_6805,name_6806,seq__6620_6796__$1,temp__6753__auto___6795__$2,vec__6617_6779,column_6780,column_info_6781,seq__6602_6773__$1,temp__6753__auto___6772__$1,vec__6599_6729,line_6730,columns_6731,seq__6566_6723__$1,temp__6753__auto___6722,inverted))
,cljs.core.sorted_map.call(null)));


var G__6807 = cljs.core.next.call(null,seq__6620_6796__$1);
var G__6808 = null;
var G__6809 = (0);
var G__6810 = (0);
seq__6620_6782 = G__6807;
chunk__6621_6783 = G__6808;
count__6622_6784 = G__6809;
i__6623_6785 = G__6810;
continue;
}
} else {
}
}
break;
}


var G__6811 = cljs.core.next.call(null,seq__6602_6773__$1);
var G__6812 = null;
var G__6813 = (0);
var G__6814 = (0);
seq__6602_6732 = G__6811;
chunk__6603_6733 = G__6812;
count__6604_6734 = G__6813;
i__6605_6735 = G__6814;
continue;
}
} else {
}
}
break;
}


var G__6815 = cljs.core.next.call(null,seq__6566_6723__$1);
var G__6816 = null;
var G__6817 = (0);
var G__6818 = (0);
seq__6566_6628 = G__6815;
chunk__6567_6629 = G__6816;
count__6568_6630 = G__6817;
i__6569_6631 = G__6818;
continue;
}
} else {
}
}
break;
}

return cljs.core.deref.call(null,inverted);
});
